# Here lies Prodigal species specific training files based on the following reference genomes. 
Open to suggestions.

**Acinetobacter baumannii**
[CP000521](https://www.ncbi.nlm.nih.gov/nuccore/CP000521)
strain: ATCC 17978

**Campylobacter jejuni**
[HE978252](https://www.ncbi.nlm.nih.gov/nuccore/HE978252)
strain: NCTC 11168-BN148 

**Enterococcus faecium**
[NC_017960.1](https://www.ncbi.nlm.nih.gov/nuccore/NC_017960.1)
strain: TX16

**Escherichia coli**
[NC_002695.1](https://www.ncbi.nlm.nih.gov/nuccore/NC_002695.1)
strain: Sakai

**Haemophilus influenzae**
[CP017811.1](https://www.ncbi.nlm.nih.gov/nuccore/CP017811.1)
strain: NML-Hia-1

**Legionella pneumophila**
[NC_002942.5](https://www.ncbi.nlm.nih.gov/nuccore/NC_002942.5)
strain: Philadelphia

**Salmonella enterica enteritidis**
[NC_011294.1](https://www.ncbi.nlm.nih.gov/nuccore/NC_011294.1)
strain: P125109

**Staphylococcus aureus**
[CP000046.1](https://www.ncbi.nlm.nih.gov/nuccore/CP000046.1)
strain: COL

**Staphylococcus haemolyticus**
[NC_007168.1](https://www.ncbi.nlm.nih.gov/nuccore/NC_007168.1)
strain: JCSC1435

**Streptococcus agalactiae**
[GCF_000007265.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000007265.1/)
strain: 2603V/R

**Streptococcus pneumoniae**
[GCF_000006885.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000006885.1)
strain: TIGR4

**Yersinia enterocolitica**
[GCF_000009345.1](https://www.ncbi.nlm.nih.gov/nuccore/NC_008800.1)
strain: 8081
